@@ -1001,7 +1001,7 @@ magui_magnification_options_save_changed (void)
 }
 #endif
 
-static gboolean
+gboolean
 magui_check_for_valid_screen (const gchar *new_val)
 {
     GdkDisplay *disp = NULL;
@@ -1975,3 +1975,13 @@ magui_magnification_options_value_add_to_widgets (Magnifier *magnifier_setting)
 
     return TRUE;
 }
+
+void
+magui_update_screen_boundary ()
+{
+    magconf_get_display_size (&display_size.size_x, &display_size.size_y);
+    gtk_spin_button_set_range ( GTK_SPIN_BUTTON (sp_zp_width),
+		(magnifier_setting->zp).left, display_size.size_x);
+    gtk_spin_button_set_range ( GTK_SPIN_BUTTON (sp_zp_height),
+		(magnifier_setting->zp).top, display_size.size_y);
+}
