@@ -1762,7 +1762,7 @@ srl_set_checked_info (Accessible *acc,
 }
 
 
-static AccessibleText*
+AccessibleText*
 srl_get_acc_text_from_children (Accessible *acc)
 {
     gint i, cnt;
